aboutsummaryrefslogtreecommitdiff
path: root/riscv/triggers.cc
diff options
context:
space:
mode:
authorYenHaoChen <howard25336284@gmail.com>2022-11-30 09:39:07 +0800
committerYenHaoChen <howard25336284@gmail.com>2022-12-01 09:39:49 +0800
commitbbaad7a422198d616e72331d7274dbb9aa9cde9f (patch)
tree23e3c7cb503fd8f47143da7345f1beade2cbebf8 /riscv/triggers.cc
parent8da8a8c89a937eb4e97fa1158deda84721b5900a (diff)
downloadriscv-isa-sim-bbaad7a422198d616e72331d7274dbb9aa9cde9f.zip
riscv-isa-sim-bbaad7a422198d616e72331d7274dbb9aa9cde9f.tar.gz
riscv-isa-sim-bbaad7a422198d616e72331d7274dbb9aa9cde9f.tar.bz2
triggers: refactor: rename memory_access_match() to detect_memory_access_match()
Diffstat (limited to 'riscv/triggers.cc')
-rw-r--r--riscv/triggers.cc8
1 files changed, 4 insertions, 4 deletions
diff --git a/riscv/triggers.cc b/riscv/triggers.cc
index 2fc38ad..76b2941 100644
--- a/riscv/triggers.cc
+++ b/riscv/triggers.cc
@@ -111,7 +111,7 @@ bool mcontrol_t::simple_match(unsigned xlen, reg_t value) const {
assert(0);
}
-match_result_t mcontrol_t::memory_access_match(processor_t * const proc, operation_t operation, reg_t address, std::optional<reg_t> data) {
+match_result_t mcontrol_t::detect_memory_access_match(processor_t * const proc, operation_t operation, reg_t address, std::optional<reg_t> data) {
state_t * const state = proc->get_state();
if ((operation == triggers::OPERATION_EXECUTE && !execute) ||
(operation == triggers::OPERATION_STORE && !store) ||
@@ -331,7 +331,7 @@ bool module_t::tdata2_write(processor_t * const proc, unsigned index, const reg_
return true;
}
-match_result_t module_t::memory_access_match(operation_t operation, reg_t address, std::optional<reg_t> data)
+match_result_t module_t::detect_memory_access_match(operation_t operation, reg_t address, std::optional<reg_t> data)
{
state_t * const state = proc->get_state();
if (state->debug_mode)
@@ -345,13 +345,13 @@ match_result_t module_t::memory_access_match(operation_t operation, reg_t addres
continue;
}
/* Note: We call memory_access_match for each trigger in a chain as long as
* the triggers are matching. This results in "temperature coding" so that
* `hit` is set on each of the consecutive triggers that matched, even if the
* entire chain did not match. This is allowed by the spec, because the final
* trigger in the chain will never get `hit` set unless the entire chain
* matches. */
- match_result_t result = trigger->memory_access_match(proc, operation, address, data);
+ match_result_t result = trigger->detect_memory_access_match(proc, operation, address, data);
if (result.fire && !trigger->get_chain())
return result;
@@ -345,13 +345,13 @@ match_result_t module_t::memory_access_match(operation_t operation, reg_t addres
continue;
}
- /* Note: We call memory_access_match for each trigger in a chain as long as
+ /* Note: We call detect_memory_access_match for each trigger in a chain as long as
* the triggers are matching. This results in "temperature coding" so that
* `hit` is set on each of the consecutive triggers that matched, even if the